==> kubernetes-model-core-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimTemplateBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PersistentVolumeClaimTemplateBuilder extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate,io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder>{
  public PersistentVolumeClaimTemplateBuilder() {
    this(false);
  }
  public PersistentVolumeClaimTemplateBuilder(java.lang.Boolean validationEnabled) {
    this(new PersistentVolumeClaimTemplate(), validationEnabled);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PersistentVolumeClaimTemplate(), validationEnabled);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance) {
    this(fluent, instance, false);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance) {
    this(instance,false);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate build() {
    PersistentVolumeClaimTemplate buildable = new PersistentVolumeClaimTemplate(fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeClaimTemplateBuilder that = (PersistentVolumeClaimTemplateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimTemplateBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PersistentVolumeClaimTemplateBuilder extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate,io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder>{
  public PersistentVolumeClaimTemplateBuilder() {
    this(false);
  }
  public PersistentVolumeClaimTemplateBuilder(java.lang.Boolean validationEnabled) {
    this(new PersistentVolumeClaimTemplate(), validationEnabled);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PersistentVolumeClaimTemplate(), validationEnabled);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance) {
    this(fluent, instance, false);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance) {
    this(instance,false);
  }
  public PersistentVolumeClaimTemplateBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate build() {
    PersistentVolumeClaimTemplate buildable = new PersistentVolumeClaimTemplate(fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeClaimTemplateBuilder that = (PersistentVolumeClaimTemplateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
